*===================================================================;
*  Title:  PROGRAM G2 CALCULATES STRATIFIED OBSERVED PROVIDER RATES 
*          FOR AHRQ PEDIATRIC QUALITY INDICATORS
*
*  Description:;
*         USES PROC SUMMARY TO CALCULATE OBSERVED RATES FOR
*         PEDIATRIC QUALITY INDICATORS ACROSS STRATIFIERS.
*         PROGRAM USES HOSPID, GPPD01, GPPD02, GPPD08, GPPD10,
*         GPPD11, GPPD12.
*
*          >>>  VERSION 3.1, March 2007 <<<
*
*===================================================================;
FILENAME CONTROL 'C:\PATHNAME\CONTROL_PDI.SAS';  *<===USER MUST modify;

%INCLUDE CONTROL;

 TITLE2 'PROGRAM: G2';
 TITLE3 'AHRQ PEDIATRIC QUALITY INDICATORS: CALCULATE STRATIFIED OBSERVED PROVIDER RATES';

 * -------------------------------------------------------------- ;
 * --- PROVIDER LEVEL MEANS ON PEDIATRIC DATA FILE  ------------- ;
 * -------------------------------------------------------------- ;

 PROC   SUMMARY DATA=ING2.&INFILEG2. MISSING;
 CLASS  HOSPID GPPD01 GPPD02 GPPD08 GPPD10 GPPD11 GPPD12;
 VAR    TPPD01 TPPD02 TPPD08 TPPD10 TPPD11 TPPD12;
 OUTPUT OUT=&OUTFILG2.
        SUM (TPPD01 TPPD02 TPPD08 TPPD10 TPPD11 TPPD12)=
        SUMWGT(TPPD01 TPPD02 TPPD08 TPPD10 TPPD11 TPPD12)=PPPD01 PPPD02 PPPD08 PPPD10 PPPD11 PPPD12
        MEAN(TPPD01 TPPD02 TPPD08 TPPD10 TPPD11 TPPD12)=OPPD01 OPPD02 OPPD08 OPPD10 OPPD11 OPPD12;
 WEIGHT DISCWT;
 RUN;

 PROC   SORT DATA=&OUTFILG2.;
 BY HOSPID GPPD01 GPPD02 GPPD08 GPPD10 GPPD11 GPPD12;
 RUN;

 DATA   OUTG2.&OUTFILG2.;
 SET    &OUTFILG2. (WHERE=(_TYPE_ IN (1,2,4,8,16,32,65,66,68,72,80,96)))
;

 LABEL
 TPPD01 = 'ACCIDENTAL PUNCTURE AND LACERATION (Num)'
 TPPD02 = 'DECUBITUS ULCER (Numerator)'
 TPPD08 = 'POSTOP HEMORRHAGE OR HEMATOMA (Num)'
 TPPD10 = 'POSTOPERATIVE SEPSIS (Numerator)' 
 TPPD11 = 'POSTOPERATIVE WOUND DEHISCENCE (Num)'
 TPPD12 = 'INFECTION DUE TO MEDICAL CARE (Num)'
 PPPD01 = 'ACCIDENTAL PUNCTURE AND LACERATION (Pop)'
 PPPD02 = 'DECUBITUS ULCER (Population)'
 PPPD08 = 'POSTOP HEMORRHAGE OR HEMATOMA (Pop)'
 PPPD10 = 'POSTOPERATIVE SEPSIS (Population)' 
 PPPD11 = 'POSTOPERATIVE WOUND DEHISCENCE (Pop)'
 PPPD12 = 'INFECTION DUE TO MEDICAL CARE (Pop)'
 OPPD01 = 'ACCIDENTAL PUNCTURE AND LACERATION (Obs)'
 OPPD02 = 'DECUBITUS ULCER (Observed)'
 OPPD08 = 'POSTOP HEMORRHAGE OR HEMATOMA (Obs)'
 OPPD10 = 'POSTOPERATIVE SEPSIS (Observed)' 
 OPPD11 = 'POSTOPERATIVE WOUND DEHISCENCE (Obs)'
 OPPD12 = 'INFECTION DUE TO MEDICAL CARE (Obs)'
 GPPD01 = 'ACCIDENTAL PUNCTURE AND LACERATION (Str)'
 GPPD02 = 'DECUBITUS ULCER (Stratif)'
 GPPD08 = 'POSTOP HEMORRHAGE OR HEMATOMA (Str)'
 GPPD10 = 'POSTOPERATIVE SEPSIS (Stratif)' 
 GPPD11 = 'POSTOPERATIVE WOUND DEHISCENCE (Str)'
 GPPD12 = 'INFECTION DUE TO MEDICAL CARE (Str)'
 _TYPE_ = 'STRATIFICATION LEVEL'
;
 DROP _FREQ_ ;

 RUN;

 * -------------------------------------------------------------- ;
 * --- CONTENTS AND MEANS OF PROVIDER OBSERVED MEANS FILE ------- ;
 * -------------------------------------------------------------- ;

 PROC   CONTENTS DATA=OUTG2.&OUTFILG2. POSITION;
 RUN;

 %MACRO MNS(PD,T);

 PROC   MEANS DATA=OUTG2.&OUTFILG2. (WHERE=(_TYPE_ IN (&T.))) N NMISS MIN MAX MEAN SUM;
 TITLE4 "SUMMARY OF PROVIDER-LEVEL RATES, PDI # &PD.";
 CLASS GPPD&PD.;
 VAR TPPD&PD. PPPD&PD. OPPD&PD.;
 RUN;

 %MEND;

 %MNS(01,96);
 %MNS(02,80);
 %MNS(08,72);
 %MNS(10,68);
 %MNS(11,66);
 %MNS(12,65);

 * -------------------------------------------------------------- ;
 * --- PRINT PROVIDER OBSERVED MEANS FILE ----------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO PRT2;

 %IF &PRINT. = 1 %THEN %DO;

 %MACRO PRT(PD,TEXT,T1,T2);

 PROC   PRINT DATA=OUTG2.&OUTFILG2. LABEL SPLIT='*';
 VAR    HOSPID GPPD&PD. TPPD&PD. PPPD&PD. OPPD&PD. ;
 LABEL HOSPID  = "HOSPID"
       GPPD&PD.   = "GPPD&PD.*(Stratif)"
       TPPD&PD.   = "TPPD&PD.*(Numerator)"
       PPPD&PD.   = "PPPD&PD.*(Denominator)"
       OPPD&PD.   = "OPPD&PD.*(Observed)"
       ;
 FORMAT TPPD&PD. PPPD&PD. 13.0 OPPD&PD. 8.6;
 FORMAT GPPD&PD. GP&PD.CAT.; 
 TITLE4 "Indicator # &PD.: &TEXT";
 WHERE _TYPE_ IN (&T1.,&T2.) AND GPPD&PD. NE .;
 RUN;

 %MEND PRT;

 %PRT(01,ACCIDENTAL PUNCTURE AND LACERATION,32,96);
 %PRT(02,DECUBITUS ULCER,16,80);
 %PRT(08,POSTOP HEMORRHAGE OR HEMATOMA,8,72);
 %PRT(10,POSTOPERATIVE SEPSIS,4,68);
 %PRT(11,POSTOPERATIVE WOUND DEHISCENCE,2,66);
 %PRT(12,INFECTION DUE TO MEDICAL CARE,1,65);

 %END;

 %MEND PRT2;

 %PRT2;

 * -------------------------------------------------------------- ;
 * --- WRITE SAS OUTPUT DATA SET TO COMMA-DELIMITED TEXT FILE --- ;
 * --- FOR EXPORT INTO SPREADSHEETS ----------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO TEXTG2;

 %IF &TEXTG2. = 1  %THEN %DO;

 DATA _NULL_;
   SET OUTG2.&OUTFILG2.;
 FILE PDTEXTG2 LRECL=2000;
 IF _N_=1 THEN PUT "PedQI" "," "Hosp Id" "," "Stratif" "," "Numerat" "," "Denomin" "," "Rate" "," "Type";

 IF _TYPE_ IN (32,96) AND GPPD01 NE . THEN 
 PUT "01 ," HOSPID 13. "," GPPD01 3. "," TPPD01 7.0 "," PPPD01 13.2 "," OPPD01 12.10 "," _TYPE_ 2.;
 IF _TYPE_ IN (16,80) AND GPPD02 NE . THEN 
 PUT "02 ," HOSPID 13. "," GPPD02 3. "," TPPD02 7.0 "," PPPD02 13.2 "," OPPD02 12.10 "," _TYPE_ 2.;
 IF _TYPE_ IN (8,72) AND GPPD08 NE . THEN 
 PUT "08 ," HOSPID 13. "," GPPD08 3. "," TPPD08 7.0 "," PPPD08 13.2 "," OPPD08 12.10 "," _TYPE_ 2.;
 IF _TYPE_ IN (4,68) AND GPPD10 NE . THEN 
 PUT "10 ," HOSPID 13. "," GPPD10 3. "," TPPD10 7.0 "," PPPD10 13.2 "," OPPD10 12.10 "," _TYPE_ 2.;
 IF _TYPE_ IN (2,66) AND GPPD11 NE . THEN 
 PUT "11 ," HOSPID 13. "," GPPD11 3. "," TPPD11 7.0 "," PPPD11 13.2 "," OPPD11 12.10 "," _TYPE_ 2.;
 IF _TYPE_ IN (1,65) AND GPPD12 NE . THEN 
 PUT "12 ," HOSPID 13. "," GPPD12 3. "," TPPD12 7.0 "," PPPD12 13.2 "," OPPD12 12.10 "," _TYPE_ 2.;

 ;
 RUN;

 %END;

 %MEND TEXTG2;

 %TEXTG2;
