*===================================================================;
*  Title:  PROGRAM P3: CALCULATES RISK-ADJUSTED PROVIDER
*          RATES FOR AHRQ PEDIATRIC QUALITY INDICATORS
*
*  Description:
*         USES PROC SCORE TO CALCULATE RISK-ADJUSTED RATES FOR
*         PEDIATRIC QUALITY INDICATORS.
*         ADJUSTS FOR: AGE, SEXCAT, DRG AND COMORBIDITY
*
*          >>>  VERSION 3.1, March 2007 <<<
*
*===================================================================;
FILENAME CONTROL "C:\PATHNAME\CONTROL_PDI.SAS"; *<==USER MUST modify;

%INCLUDE CONTROL;

%MACRO LBL1;
    LABEL RPPD01 = 'ACCIDENTAL PUNCTURE AND LACERATION (RA)'
          RPPD02 = 'DECUBITUS ULCER (Risk Adj)'
          RPPD04 = 'IATROGENIC PNEUMOTHORAX NEONATE (RA)'
          RPPD05 = 'IATROGENIC PNEUMOTHORAX (Risk Adj)'
          RPPD06 = 'IN-HOSP MORT PEDIATRIC HEART SURG (RA)'
          RPPD08 = 'POSTOP HEMORRHAGE OR HEMATOMA (RA)'
          RPPD09 = 'POSTOP RESPIRATORY FAILURE (Risk Adj)'
          RPPD10 = 'POSTOPERATIVE SEPSIS (Risk Adj)' 
          RPPD11 = 'POSTOPERATIVE WOUND DEHISCENCE (RA)'
          RPPD12 = 'INFECTION DUE TO MEDICAL CARE (RA)'
          LPPD01 = 'ACCIDENTAL PUNCTURE AND LACERATION (LL)'
          LPPD02 = 'DECUBITUS ULCER (Lower CL)'
          LPPD04 = 'IATROGENIC PNEUMOTHORAX NEONATE (LL)'
          LPPD05 = 'IATROGENIC PNEUMOTHORAX (Lower CL)'
          LPPD06 = 'IN-HOSP MORT PEDIATRIC HEART SURG (LL)'
          LPPD08 = 'POSTOP HEMORRHAGE OR HEMATOMA (LL)'
          LPPD09 = 'POSTOP RESPIRATORY FAILURE (Lower CL)'
          LPPD10 = 'POSTOPERATIVE SEPSIS (Lower CL)' 
          LPPD11 = 'POSTOPERATIVE WOUND DEHISCENCE (LL)'
          LPPD12 = 'INFECTION DUE TO MEDICAL CARE (LL)'
          UPPD01 = 'ACCIDENTAL PUNCTURE AND LACERATION (UL)'
          UPPD02 = 'DECUBITUS ULCER (Upper CL)'
          UPPD04 = 'IATROGENIC PNEUMOTHORAX NEONATE (UL)'
          UPPD05 = 'IATROGENIC PNEUMOTHORAX (Upper CL)'
          UPPD06 = 'IN-HOSP MORT PEDIATRIC HEART SURG (UL)'
          UPPD08 = 'POSTOP HEMORRHAGE OR HEMATOMA (UL)'
          UPPD09 = 'POSTOP RESPIRATORY FAILURE (Lower CL)'
          UPPD10 = 'POSTOPERATIVE SEPSIS (Upper CL)' 
          UPPD11 = 'POSTOPERATIVE WOUND DEHISCENCE (UL)'
          UPPD12 = 'INFECTION DUE TO MEDICAL CARE (UL)'
          ;

 * -------------------------------------------------------------- ;
 * --- RE-LABEL DAY DEPENDENT INDICATORS ------------------------ ;
 * -------------------------------------------------------------- ;
 %IF &PRDAY. = 0 %THEN %DO;
    LABEL RPPD02 = 'DECUBITUS ULCER-NO PRDAY (Risk Adj)'
          RPPD08 = 'POSTOP HEMOR OR HEMAT-NO PRDAY (RA)'
          RPPD09 = 'POSTOP RESP FAILURE-NO PRDAY (Risk Adj)'
          RPPD11 = 'POSTOP WOUND DEHISCENCE-NO PRDAY (RA)'
          ;
 %END;

%MEND;

%MACRO LBL2;
    LABEL SPPD01 = 'ACCIDENTAL PUNCTURE AND LACERATION (Smthd)'
          SPPD02 = 'DECUBITUS ULCER (Smoothed)'
          SPPD04 = 'IATROGENIC PNEUMOTHORAX NEONATE (Smthd)'
          SPPD05 = 'IATROGENIC PNEUMOTHORAX (Smoothed)'
          SPPD06 = 'IN-HOSP MORT PEDIATRIC HEART SURG (Smthd)'
          SPPD08 = 'POSTOP HEMORRHAGE OR HEMATOMA (Smthd)'
          SPPD09 = 'POSTOP RESPIRATORY FAILURE (Smoothed)'
          SPPD10 = 'POSTOPERATIVE SEPSIS (Smoothed)' 
          SPPD11 = 'POSTOPERATIVE WOUND DEHISCENCE (Smthd)'
          SPPD12 = 'INFECTION DUE TO MEDICAL CARE (Smthd)'
          XPPD01 = 'ACCIDENTAL PUNCTURE AND LACERATION (SmtSE)'
          XPPD02 = 'DECUBITUS ULCER (Smthe SE)'
          XPPD04 = 'IATROGENIC PNEUMOTHORAX NEONATE (SmtSE)'
          XPPD05 = 'IATROGENIC PNEUMOTHORAX (Smthe SE)'
          XPPD06 = 'IN-HOSP MORT PEDIATRIC HEART SURG (SmtSE)'
          XPPD08 = 'POSTOP HEMORRHAGE OR HEMATOMA (SmtSE)'
          XPPD09 = 'POSTOP RESPIRATORY FAILURE (Smthe SE)'
          XPPD10 = 'POSTOPERATIVE SEPSIS (Smthe SE)' 
          XPPD11 = 'POSTOPERATIVE WOUND DEHISCENCE (SmtSE)'
          XPPD12 = 'INFECTION DUE TO MEDICAL CARE (SmtSE)'
          ;

 * -------------------------------------------------------------- ;
 * --- RE-LABEL DAY DEPENDENT INDICATORS ------------------------ ;
 * -------------------------------------------------------------- ;
 %IF &PRDAY. = 0 %THEN %DO;
    LABEL SPPD02 = 'DECUBITUS ULCER-NO PRDAY (Smoothed)'
          SPPD08 = 'POSTOP HEMOR OR HEMAT-NO PRDAY (Smthd)'
          SPPD09 = 'POSTOP RESP FAILURE-NO PRDAY (Smoothed)'
          SPPD11 = 'POSTOP WOUND DEHISCENCE-NO PRDAY (Smthd)'
          ;
 %END;

%MEND;

%MACRO LBL3;
    LABEL EPPD01 = 'ACCIDENTAL PUNCTURE AND LACERATION (Exp)'
          EPPD02 = 'DECUBITUS ULCER (Expected)'
          EPPD04 = 'IATROGENIC PNEUMOTHORAX NEONATE (Exp)'
          EPPD05 = 'IATROGENIC PNEUMOTHORAX (Expected)'
          EPPD06 = 'IN-HOSP MORT PEDIATRIC HEART SURG (Exp)'
          EPPD08 = 'POSTOP HEMORRHAGE OR HEMATOMA (Exp)'
          EPPD09 = 'POSTOP RESPIRATORY FAILURE (Expected)'
          EPPD10 = 'POSTOPERATIVE SEPSIS (Expected)' 
          EPPD11 = 'POSTOPERATIVE WOUND DEHISCENCE (Exp)'
          EPPD12 = 'INFECTION DUE TO MEDICAL CARE (Exp)'
          ;

 * -------------------------------------------------------------- ;
 * --- RE-LABEL DAY DEPENDENT INDICATORS ------------------------ ;
 * -------------------------------------------------------------- ;
 %IF &PRDAY. = 0 %THEN %DO;
    LABEL EPPD02 = 'DECUBITUS ULCER-NO PRDAY (Expected)'
          EPPD08 = 'POSTOP HEMOR OR HEMAT-NO PRDAY (Exp)'
          EPPD09 = 'POSTOP RESP FAILURE-NO PRDAY (Expected)'
          EPPD11 = 'POSTOP WOUND DEHISCENCE-NO PRDAY (Exp)'
          ;
 %END;

%MEND;

%MACRO PRT(PD,TEXT,CASE);
    PROC PRINT DATA=OUTP3.&OUTFILP3. LABEL SPLIT="*";
 %IF &CASE. = 2 %THEN %DO;
        VAR HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT 
            TPPD&PD.;
        LABEL HOSPID  = "HOSPID"
              BWHTCAT = "BWHTCAT"
              AGEDCAT = "AGEDCAT"
              PAGECAT = "PAGECAT"
              SEXCAT  = "SEXCAT"
              PAYCAT  = "PAYCAT"
              RACECAT = "RACECAT"
              TPPD&PD. = "TPPD&PD.*(Volume)"
              ;
        FORMAT BWHTCAT BWHTCAT.
               AGEDCAT AGEDCAT.
               PAGECAT PAGECAT.
               SEXCAT SEXCAT.
               PAYCAT PAYCAT.
               RACECAT RACECAT.
               TPPD&PD. 13.0;
 %END;
 %ELSE %IF &CASE. = 1 %THEN %DO;
        VAR HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT
            TPPD&PD. PPPD&PD. OPPD&PD.;
        LABEL HOSPID  = "HOSPID"
              BWHTCAT = "BWHTCAT"
              AGEDCAT = "AGEDCAT"
              PAGECAT = "PAGECAT"
              SEXCAT  = "SEXCAT"
              PAYCAT  = "PAYCAT"
              RACECAT = "RACECAT"
              TPPD&PD. = "TPPD&PD.*(Numerator)"
              PPPD&PD. = "PPPD&PD.*(Denominator)"
              OPPD&PD. = "OPPD&PD.*(Observed)"
              ;
        FORMAT BWHTCAT BWHTCAT.
               AGEDCAT AGEDCAT.
               PAGECAT PAGECAT.
               SEXCAT SEXCAT.
               PAYCAT PAYCAT.
               RACECAT RACECAT.
               TPPD&PD. PPPD&PD. 13.0 OPPD&PD. 8.6;
 %END;
 %ELSE %DO;
        VAR HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT
            TPPD&PD. PPPD&PD. OPPD&PD. EPPD&PD. RPPD&PD. LPPD&PD. UPPD&PD. SPPD&PD. XPPD&PD.;
        LABEL HOSPID  = "HOSPID"
              BWHTCAT = "BWHTCAT"
              AGEDCAT = "AGEDCAT"
              PAGECAT = "PAGECAT"
              SEXCAT  = "SEXCAT"
              PAYCAT  = "PAYCAT"
              RACECAT = "RACECAT"
              TPPD&PD. = "TPPD&PD.*(Numerator)"
              PPPD&PD. = "PPPD&PD.*(Denominator)"
              OPPD&PD. = "OPPD&PD.*(Observed)"
              EPPD&PD. = "EPPD&PD.*(Expected)"
              RPPD&PD. = "RPPD&PD.*(Risk Adj)"
              LPPD&PD. = "LPPD&PD.*(Lower CL)"
              UPPD&PD. = "UPPD&PD.*(Upper CL)"
              SPPD&PD. = "SPPD&PD.*(Smoothed)"
              XPPD&PD. = "XPPD&PD.*(Smoth SE)"
          ;
        FORMAT BWHTCAT BWHTCAT.
               AGEDCAT AGEDCAT.
               PAGECAT PAGECAT.
               SEXCAT SEXCAT.
               PAYCAT PAYCAT.
               RACECAT RACECAT.
               TPPD&PD. PPPD&PD. 13.0 OPPD&PD. RPPD&PD. SPPD&PD. EPPD&PD. 8.6;
 %END;
        TITLE4 "FINAL OUTPUT";
        TITLE5 "Indicator # &PD.: &TEXT";

    RUN;

%MEND;

%MACRO PRT2;
   %IF &PRINT. = 1 %THEN %DO;
       %PRT(01,ACCIDENTAL PUNCTURE AND LACERATION,0);
       %PRT(02,DECUBITUS ULCER,0);
       %PRT(03,FOREIGN BODY LEFT IN DURING PROC,1);
       %PRT(04,IATROGENIC PNEUMOTHORAX NEONATE,0);
       %PRT(05,IATROGENIC PNEUMOTHORAX,0);
       %PRT(06,IN-HOSP MORT PEDIATRIC HEART SURG,0);
       %PRT(07,VOLUME PEDIATRIC HEART SURG,2);
       %PRT(08,POST-OPERATIVE HEMORRHAGE OR HEMATOMA,0);
       %PRT(09,POST-OPERATIVE RESPIRATORY FAILURE,0);
       %PRT(10,POST-OPERATIVE SEPSIS,0);
       %PRT(11,POST-OPERATIVE WOUND DEHISCENCE,0);
       %PRT(12,INFECTION DUE TO MEDICAL CARE,0);
       %PRT(13,TRANSFUSION REACTION,1);
   %END;
%MEND;

%MACRO TEXT;
   %IF &TEXTP3. = 1  %THEN %DO;
       DATA _NULL_;
          SET OUTP3.&OUTFILP3;
          FILE PDTEXTP3 LRECL=4000;
          IF _N_=1 THEN PUT
            "Hosp Id" "," "BWht" "," "AgeD" "," "Age"  "," "Sex"  "," "Payer" "," "Race"  "," "Type" ","
            "TPPD01" "," "TPPD02" "," "TPPD03" "," "TPPD04" ","
            "TPPD05" "," "TPPD06" "," "TPPD07" "," "TPPD08" ","
            "TPPD09" "," "TPPD10" "," "TPPD11" "," "TPPD12" ","
            "TPPD13" ","
            "PPPD01" "," "PPPD02" "," "TPPD03" "," "PPPD04" ","
            "PPPD05" "," "PPPD06" ","              "PPPD08" ","
            "PPPD09" "," "PPPD10" "," "PPPD11" "," "PPPD12" ","
            "PPPD13" ","
            "OPPD01" "," "OPPD02" "," "OPPD03" "," "OPPD04" ","
            "OPPD05" "," "OPPD06" ","              "OPPD08" ","
            "OPPD09" "," "OPPD10" "," "OPPD11" "," "OPPD12" ","
            "OPPD13" ","
            "EPPD01" "," "EPPD02" ","              "EPPD04" ","
            "EPPD05" "," "EPPD06" ","              "EPPD08" ","
            "EPPD09" "," "EPPD10" "," "EPPD11" "," "EPPD12" ","
            "RPPD01" "," "RPPD02" ","              "RPPD04" ","
            "RPPD05" "," "RPPD06" ","              "RPPD08" ","
            "RPPD09" "," "RPPD10" "," "RPPD11" "," "RPPD12" ","
            "LPPD01" "," "LPPD02" ","              "LPPD04" ","
            "LPPD05" "," "LPPD06" ","              "LPPD08" ","
            "LPPD09" "," "LPPD10" "," "LPPD11" "," "LPPD12" ","
            "UPPD01" "," "UPPD02" ","              "UPPD04" ","
            "UPPD05" "," "UPPD06" ","              "UPPD08" ","
            "UPPD09" "," "UPPD10" "," "UPPD11" "," "UPPD12" ","
            "SPPD01" "," "SPPD02" ","              "SPPD04" ","
            "SPPD05" "," "SPPD06" ","              "SPPD08" ","
            "SPPD09" "," "SPPD10" "," "SPPD11" "," "SPPD12" ","
            "XPPD01" "," "XPPD02" ","              "XPPD04" ","
            "XPPD05" "," "XPPD06" ","              "XPPD08" ","
            "XPPD09" "," "XPPD10" "," "XPPD11" "," "XPPD12"
            ;
        PUT HOSPID 13. "," BWHTCAT 3. "," AGEDCAT 3. "," PAGECAT 3. "," SEXCAT 3. "," PAYCAT 3. "," RACECAT 3. "," _TYPE_ 2. ","
           (TPPD01-TPPD13) (7.0 ",") "," 
           (PPPD01-PPPD06 PPPD08-PPPD13) (13.2 ",") ","
           (OPPD01-OPPD06 OPPD08-OPPD13) (12.10 ",") ","
           (EPPD01 EPPD02 EPPD04-EPPD06 EPPD08-EPPD12) (12.10 ",") ","
           (RPPD01 RPPD02 RPPD04-RPPD06 RPPD08-RPPD12) (12.10 ",") ","
           (LPPD01 LPPD02 LPPD04-LPPD06 LPPD08-LPPD12) (12.10 ",") ","
           (UPPD01 UPPD02 UPPD04-UPPD06 UPPD08-UPPD12) (12.10 ",") ","
           (SPPD01 SPPD02 SPPD04-SPPD06 SPPD08-SPPD12) (12.10 ",") ","
           (XPPD01 XPPD02 XPPD04-XPPD06 XPPD08-XPPD12) (12.10 ",");
       RUN;
   %END;
 %MEND;


TITLE2 'PROGRAM P3 PART I';
TITLE3 'AHRQ PEDIATRIC QUALITY INDICATORS: CALCULATE RISK-ADJUSTED PROVIDER RATES';

* -------------------------------------------------------------- ;
* --- PDI ADJUSTED RATES  -------------------------------------- ;
* -------------------------------------------------------------- ;
* --- THIS STEP SELECTS THE OBSERVATIONS FROM THE PROGRAM 1    - ;
* --- OUTPUT FOR EACH PEDIATRIC QUALITY INDICATOR IN TURN.     - ;
* --- EACH ITERATION PASSES VARIABLES THAT CONTROL THE         - ;
* --- COVARIATES FOR THAT PEDIATRIC QUALITY INDICATOR:         - ;
* --- N - OBSERVATION NUMBER FROM THE COVAR FILE               - ;
* ---     ALSO IDENTIFIES THE FORMAT USED TO INDEX COVARIATES  - ;
* --- PD - THE PEDIATRIC QUALITY INDICATOR NAME WITHOUT THE    - ;
* ---      PREFIX (P)                                          - ;
* --- DQ - NUMBER OF DRG COVARIATES                            - ;
* --- MQ - NUMBER OF MDC COVARIATES                            - ;
* -------------------------------------------------------------- ;

 %LET COMOB = CCS4   CCS6   CCS21  CCS33  CCS35  CCS38  CCS39  CCS41  CCS42  CCS48
              CCS51  CCS52  CCS56  CCS57  CCS58  CCS62  CCS63  CCS65  CCS67  CCS81
              CCS82  CCS83  CCS85  CCS95  CCS96  CCS98  CCS103 CCS105 CCS106 CCS108
              CCS133 CCS138 CCS151 CCS158 CCS161 CCS210 CCS211 CCS213 CCS214 CCS215
              CCS216 CCS217 CCS219 CCS221 CCS224 CCS227
 ;

 %MACRO MOD3(N,PD,DQ,MQ);

    * --- THIS SET CREATES TEMP1 WHICH CONTAINS THE DEPENDENT      - ;
    * --- VARIABLE (TPD) AND INDEPENDENT VARIABLES USED IN         - ;
    * --- REGRESSION                                               - ;

    DATA TEMP1(KEEP=KEY HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT 
                    T&PD. CV1-CV162 DISCWT);
    LENGTH CV1-CV162 DIDX 3;
    SET INP3.&INFILP3X.;

        * --- KEEP ONLY DISCHARGES NEEDED FOR THIS PD ------------------ ;
        IF T&PD. NE .;

        * --- INITIALIZE COVARIATE ------------------------------------- ;

        ARRAY CVARRY{162} CV1-CV162;
        ARRAY CCSARRY{46} &COMOB.;

        DO I = 1 TO 162;
           CVARRY(I) = 0;
        END;

        DIDX = PUT(PUT(DRG,Z3.),$DRGFMT.);

        %MACRO CV;

        %IF &N. = 01 %THEN %DO;

        ARRAY DRGARRY1{&DQ.} _temporary_ 
        (
102 103 307 315 401 
420 501 502 505 507 
536 541 602 603 606 
610 611 612 623 701 
702 803 809 813 816 
818 839 840 841 1002 
1102 1103 1105 1305 1502 
1503 1505 1506 1602 1801 
2104 2403 7702
        );

        ARRAY MDCARRY1{&MQ.} _temporary_ 
        (
1 3 4 5 6
7 8 10 11 13
16 17 21
        );

        UNGROUP = 0;

        IF DIDX IN (
        7704, 7705, 8801, 8802, 8803,
        8804, 8805, 8806
        )
        THEN UNGROUP = 1;
        ELSE IF DIDX IN (
102,103,307,315,401,
420,501,502,505,507,
536,541,602,603,606,
610,611,612,623,701,
702,803,809,813,816,
818,839,840,841,1002,
1102,1103,1105,1305,1502,
1503,1505,1506,1602,1801,
2104,2403,7702
        )
        THEN DO;
           DO I = 1 TO &DQ.;
              IF DRGARRY1(I) = DIDX THEN CVARRY(14+I) = 1;
           END;
        END;
        ELSE IF MDC IN (
1, 3, 4, 5, 6,
7, 8, 10, 11, 13,
16, 17, 21
        ) 
        THEN DO;
           DO I = 1 TO &MQ.;
              IF MDCARRY1(I) = MDC THEN CVARRY(14+&DQ.+I) = 1;
           END;
        END;
        ELSE IF MDC IN (
2, 12, 23
        ) THEN CVARRY(14+&DQ.+&MQ.+1) = 1;
        ELSE CVARRY(14+&DQ.+&MQ.+2) = 1;

        DO I = 1 TO 46;
           CVARRY(14+&DQ.+&MQ.+2+I) = CCSARRY(I);
        END;

        IF H&PD. IN (1) THEN CVARRY(14+&DQ.+&MQ.+2+46+1) = 1;
        IF H&PD. IN (2) THEN CVARRY(14+&DQ.+&MQ.+2+46+2) = 1;
        IF H&PD. IN (3) THEN CVARRY(14+&DQ.+&MQ.+2+46+3) = 1;
        IF H&PD. IN (4) THEN CVARRY(14+&DQ.+&MQ.+2+46+4) = 1;
        IF H&PD. IN (5) THEN CVARRY(14+&DQ.+&MQ.+2+46+5) = 1;
        IF H&PD. IN (6) THEN CVARRY(14+&DQ.+&MQ.+2+46+6) = 1;
        IF H&PD. IN (7) THEN CVARRY(14+&DQ.+&MQ.+2+46+7) = 1;

        %END;
        %ELSE %IF &N. = 02 %THEN %DO;

        ARRAY DRGARRY1{&DQ.} _temporary_ 
        (
102 103 107 126 405 
412 416 420 505 533 
602 606 621 803 822 
840 1012 1103 1105 1114
1607 1708 1801 1803 2302 
2401 2403 
        );

        ARRAY MDCARRY1{&MQ.} _temporary_ 
        (
1 4 5 6 8
10 17 18 21 24
        );

        UNGROUP = 0;

        IF DIDX IN (
        7704, 7705, 8801, 8802, 8803,
        8804, 8805, 8806
        )
        THEN UNGROUP = 1;
        ELSE IF DIDX IN (
102, 103, 107, 126, 405, 
412, 416, 420, 505, 533, 
602, 606, 621, 803, 822, 
840, 1012, 1103, 1105, 1114,
1607, 1708, 1801, 1803, 2302, 
2401, 2403
        )
        THEN DO;
           DO I = 1 TO &DQ.;
              IF DRGARRY1(I) = DIDX THEN CVARRY(14+I) = 1;
           END;
        END;
        ELSE IF MDC IN (
1, 4, 5, 6, 8,
10, 17, 18, 21, 24
        ) 
        THEN DO;
           DO I = 1 TO &MQ.;
              IF MDCARRY1(I) = MDC THEN CVARRY(14+&DQ.+I) = 1;
           END;
        END;
        ELSE IF MDC IN (
7, 11, 22, 23, 25
        ) THEN CVARRY(14+&DQ.+&MQ.+1) = 1;
        ELSE CVARRY(14+&DQ.+&MQ.+2) = 1;

        DO I = 1 TO 46;
           CVARRY(14+&DQ.+&MQ.+2+I) = CCSARRY(I);
        END;

        IF G&PD. IN (1) THEN CVARRY(14+&DQ.+&MQ.+2+46+1) = 1;
        IF G&PD. IN (2) THEN CVARRY(14+&DQ.+&MQ.+2+46+2) = 1;

        %END;
        %ELSE %IF &N. = 04 %THEN %DO;

        ARRAY DRGARRY1{&DQ.} _temporary_ 
        (
1502 8888
        );

        ARRAY MDCARRY1{&MQ.} _temporary_ 
        (
888 999
        );

        UNGROUP = 0;

        IF DIDX IN (
        7704, 7705, 8801, 8802, 8803,
        8804, 8805, 8806
        )
        THEN UNGROUP = 1;
        ELSE IF DIDX IN (
1502, 8888
        )
        THEN DO;
           DO I = 1 TO &DQ.;
              IF DRGARRY1(I) = DIDX THEN CVARRY(14+I) = 1;
           END;
        END;
        ELSE IF MDC IN (
888, 999
        ) 
        THEN DO;
           DO I = 1 TO &MQ.;
              IF MDCARRY1(I) = MDC THEN CVARRY(14+&DQ.+I) = 1;
           END;
        END;
        ELSE IF MDC IN (
777
        ) THEN CVARRY(14+&DQ.+&MQ.+1) = 1;
        ELSE CVARRY(14+&DQ.+&MQ.+2) = 1;

        DO I = 1 TO 46;
           CVARRY(14+&DQ.+&MQ.+2+I) = CCSARRY(I);
        END;

        %END;
        %ELSE %IF &N. = 05 %THEN %DO;

        ARRAY DRGARRY1{&DQ.} _temporary_ 
        (
102 420 512 840 1502 
1505
        );

        ARRAY MDCARRY1{&MQ.} _temporary_ 
        (
1 3 4 5 6
7 8 10 11 15
17 21
        );

        UNGROUP = 0;

        IF DIDX IN (
        7704, 7705, 8801, 8802, 8803,
        8804, 8805, 8806
        )
        THEN UNGROUP = 1;
        ELSE IF DIDX IN (
102, 420, 512, 840, 1502,
1505
        )
        THEN DO;
           DO I = 1 TO &DQ.;
              IF DRGARRY1(I) = DIDX THEN CVARRY(14+I) = 1;
           END;
        END;
        ELSE IF MDC IN (
1, 3, 4, 5, 6,
7, 8, 10, 11, 15,
17, 21
        ) 
        THEN DO;
           DO I = 1 TO &MQ.;
              IF MDCARRY1(I) = MDC THEN CVARRY(14+&DQ.+I) = 1;
           END;
        END;
        ELSE IF MDC IN (
16, 22, 23, 24, 25
        ) THEN CVARRY(14+&DQ.+&MQ.+1) = 1;
        ELSE CVARRY(14+&DQ.+&MQ.+2) = 1;

        DO I = 1 TO 46;
           CVARRY(14+&DQ.+&MQ.+2+I) = CCSARRY(I);
        END;

        %END;
        %ELSE %IF &N. = 06 %THEN %DO;

        ARRAY DRGARRY1{&DQ.} _temporary_ 
        (
8888 9999
        );

        ARRAY MDCARRY1{&MQ.} _temporary_ 
        (
888 999
        );

        UNGROUP = 0;

        IF DIDX IN (
        7704, 7705, 8801, 8802, 8803,
        8804, 8805, 8806
        )
        THEN UNGROUP = 1;
        ELSE IF DIDX IN (
8888, 9999
        )
        THEN DO;
           DO I = 1 TO &DQ.;
              IF DRGARRY1(I) = DIDX THEN CVARRY(14+I) = 1;
           END;
        END;
        ELSE IF MDC IN (
888, 999
        ) 
        THEN DO;
           DO I = 1 TO &MQ.;
              IF MDCARRY1(I) = MDC THEN CVARRY(14+&DQ.+I) = 1;
           END;
        END;
        ELSE IF MDC IN (
777
        ) THEN CVARRY(14+&DQ.+&MQ.+1) = 1;
        ELSE CVARRY(14+&DQ.+&MQ.+2) = 1;

        DO I = 1 TO 46;
           CVARRY(14+&DQ.+&MQ.+2+I) = CCSARRY(I);
        END;

        IF H&PD. IN (1) THEN CVARRY(14+&DQ.+&MQ.+2+46+1) = 1;
        IF H&PD. IN (2) THEN CVARRY(14+&DQ.+&MQ.+2+46+2) = 1;
        IF H&PD. IN (3) THEN CVARRY(14+&DQ.+&MQ.+2+46+3) = 1;
        IF H&PD. IN (4) THEN CVARRY(14+&DQ.+&MQ.+2+46+4) = 1;
        IF H&PD. IN (5) THEN CVARRY(14+&DQ.+&MQ.+2+46+5) = 1;
        IF H&PD. IN (6) THEN CVARRY(14+&DQ.+&MQ.+2+46+6) = 1;
        IF H&PD. IN (0) THEN CVARRY(14+&DQ.+&MQ.+2+46+7) = 1;

        IF MULTIPLE        THEN CVARRY(14+&DQ.+&MQ.+2+46+8) = 1;
        IF MDX4D           THEN CVARRY(14+&DQ.+&MQ.+2+46+9) = 1;
        IF STRCABN         THEN CVARRY(14+&DQ.+&MQ.+2+46+10) = 1;

        %END;
        %ELSE %IF &N. = 08 %THEN %DO;

        ARRAY DRGARRY1{&DQ.} _temporary_ 
        (
310 502 505 507
        );

        ARRAY MDCARRY1{&MQ.} _temporary_ 
        (
3 8
        );

        UNGROUP = 0;

        IF DIDX IN (
        7704, 7705, 8801, 8802, 8803,
        8804, 8805, 8806
        )
        THEN UNGROUP = 1;
        ELSE IF DIDX IN (
310, 502, 505, 507
        )
        THEN DO;
           DO I = 1 TO &DQ.;
              IF DRGARRY1(I) = DIDX THEN CVARRY(14+I) = 1;
           END;
        END;
        ELSE IF MDC IN (
3, 8
        ) 
        THEN DO;
           DO I = 1 TO &MQ.;
              IF MDCARRY1(I) = MDC THEN CVARRY(14+&DQ.+I) = 1;
           END;
        END;
        ELSE IF MDC IN (
5, 7, 9, 12, 18,
21, 22, 23, 25
        ) THEN CVARRY(14+&DQ.+&MQ.+1) = 1;
        ELSE CVARRY(14+&DQ.+&MQ.+2) = 1;

        DO I = 1 TO 46;
           CVARRY(14+&DQ.+&MQ.+2+I) = CCSARRY(I);
        END;

        IF G&PD. IN (1) THEN CVARRY(14+&DQ.+&MQ.+2+46+1) = 1;
        IF G&PD. IN (2) THEN CVARRY(14+&DQ.+&MQ.+2+46+2) = 1;

        %END;
        %ELSE %IF &N. = 09 %THEN %DO;

        ARRAY DRGARRY1{&DQ.} _temporary_ 
        (
102 103 106 304 307
310 312 314 315 602
606 610 701 803 807
816 818 839 840 1101
1103 1801 2104 2403 
        );

        ARRAY MDCARRY1{&MQ.} _temporary_ 
        (
2 3 6 7 8
10 11 16 17
        );

        UNGROUP = 0;

        IF DIDX IN (
        7704, 7705, 8801, 8802, 8803,
        8804, 8805, 8806
        )
        THEN UNGROUP = 1;
        ELSE IF DIDX IN (
102, 103, 106, 304, 307, 
310, 312, 314, 315, 602, 
606, 610, 701, 803, 807, 
816, 818, 839, 840, 1101, 
1103, 1801, 2104, 2403 
        )
        THEN DO;
           DO I = 1 TO &DQ.;
              IF DRGARRY1(I) = DIDX THEN CVARRY(14+I) = 1;
           END;
        END;
        ELSE IF MDC IN (
2, 3, 6, 7, 8, 
10, 11, 16, 17 
        ) 
        THEN DO;
           DO I = 1 TO &MQ.;
              IF MDCARRY1(I) = MDC THEN CVARRY(14+&DQ.+I) = 1;
           END;
        END;
        ELSE IF MDC IN (
1, 19, 22, 23, 24, 
25
        ) THEN CVARRY(14+&DQ.+&MQ.+1) = 1;
        ELSE CVARRY(14+&DQ.+&MQ.+2) = 1;

        DO I = 1 TO 46;
           CVARRY(14+&DQ.+&MQ.+2+I) = CCSARRY(I);
        END;

        %END;
        %ELSE %IF &N. = 10 %THEN %DO;

        ARRAY DRGARRY1{&DQ.} _temporary_ 
        (
102 103 401 402 501 
502 505 507 536 602 
603 604 606 613 701 
706 818 840 1008 1101
1103 1109 1603 1701 1702
1705 1706 2104 2206 2208 
2401 2402 2403 7701 7702 
7703
        );

        ARRAY MDCARRY1{&MQ.} _temporary_ 
        (
1 2 3 5 6
7 8 9 10 11
16
        );

        UNGROUP = 0;

        IF DIDX IN (
        7704, 7705, 8801, 8802, 8803,
        8804, 8805, 8806
        )
        THEN UNGROUP = 1;
        ELSE IF DIDX IN (
102, 103, 401, 402, 501, 
502, 505, 507, 536, 602, 
603, 604, 606, 613, 701, 
706, 818, 840, 1008, 1101,
1103, 1109, 1603, 1701, 1702,
1705, 1706, 2104, 2206, 2208, 
2401, 2402, 2403, 7701, 7702, 
7703
        )
        THEN DO;
           DO I = 1 TO &DQ.;
              IF DRGARRY1(I) = DIDX THEN CVARRY(14+I) = 1;
           END;
        END;
        ELSE IF MDC IN (
1, 2, 3, 5, 6,
7, 8, 9, 10, 11,
16
        ) 
        THEN DO;
           DO I = 1 TO &MQ.;
              IF MDCARRY1(I) = MDC THEN CVARRY(14+&DQ.+I) = 1;
           END;
        END;
        ELSE IF MDC IN (
4, 17, 19, 25
        ) THEN CVARRY(14+&DQ.+&MQ.+1) = 1;
        ELSE CVARRY(14+&DQ.+&MQ.+2) = 1;

        DO I = 1 TO 46;
           CVARRY(14+&DQ.+&MQ.+2+I) = CCSARRY(I);
        END;

        IF G&PD. IN (1,9) THEN CVARRY(14+&DQ.+&MQ.+2+46+1) = 1;
        IF G&PD. IN (2) THEN CVARRY(14+&DQ.+&MQ.+2+46+2) = 1;
        IF G&PD. IN (3) THEN CVARRY(14+&DQ.+&MQ.+2+46+3) = 1;
        IF G&PD. IN (4) THEN CVARRY(14+&DQ.+&MQ.+2+46+4) = 1;
        IF H&PD. IN (1) THEN CVARRY(14+&DQ.+&MQ.+2+46+5) = 1;
        IF H&PD. IN (2) THEN CVARRY(14+&DQ.+&MQ.+2+46+6) = 1;
        IF H&PD. IN (3) THEN CVARRY(14+&DQ.+&MQ.+2+46+7) = 1;

        %END;
        %ELSE %IF &N. = 11 %THEN %DO;

        ARRAY DRGARRY1{&DQ.} _temporary_ 
        (
602 606
        );

        ARRAY MDCARRY1{&MQ.} _temporary_ 
        (
6 15
        );

        UNGROUP = 0;

        IF DIDX IN (
        7704, 7705, 8801, 8802, 8803,
        8804, 8805, 8806
        )
        THEN UNGROUP = 1;
        ELSE IF DIDX IN (
602, 606
        )
        THEN DO;
           DO I = 1 TO &DQ.;
              IF DRGARRY1(I) = DIDX THEN CVARRY(14+I) = 1;
           END;
        END;
        ELSE IF MDC IN (
6, 15
        ) 
        THEN DO;
           DO I = 1 TO &MQ.;
              IF MDCARRY1(I) = MDC THEN CVARRY(14+&DQ.+I) = 1;
           END;
        END;
        ELSE IF MDC IN (
777
        ) THEN CVARRY(14+&DQ.+&MQ.+1) = 1;
        ELSE CVARRY(14+&DQ.+&MQ.+2) = 1;

        DO I = 1 TO 46;
           CVARRY(14+&DQ.+&MQ.+2+I) = CCSARRY(I);
        END;

        IF G&PD. IN (1,9) THEN CVARRY(14+&DQ.+&MQ.+2+46+1) = 1;
        IF G&PD. IN (2) THEN CVARRY(14+&DQ.+&MQ.+2+46+2) = 1;
        IF G&PD. IN (3) THEN CVARRY(14+&DQ.+&MQ.+2+46+3) = 1;
        IF G&PD. IN (4) THEN CVARRY(14+&DQ.+&MQ.+2+46+4) = 1;
        IF G&PD. IN (5) THEN CVARRY(14+&DQ.+&MQ.+2+46+5) = 1;

        %END;
        %ELSE %IF &N. = 12 %THEN %DO;

        ARRAY DRGARRY1{&DQ.} _temporary_ 
        (
102 108 115 120 126
321 401 402 405 412
416 420 501 502 505
507 516 518 528 533
602 603 604 606 610
611 613 615 618 621
623 701 710 711 807
822 823 824 915 1008
1010 1012 1013 1014 1101
1103 1109 1110 1114 1121
1502 1503 1505 1605 1606 
1607 1701 1703 1704 1708 
1713 1801 1803 1807 1808 
2104 2111 2206 2208 2302 
2403 2404 2502 7701 7702 
7703
        );

        ARRAY MDCARRY1{&MQ.} _temporary_ 
        (
1 3 4 5 6
7 8 9 10 11
15 16 17 21 22
23 24
        );

        UNGROUP = 0;

        IF DIDX IN (
        7704, 7705, 8801, 8802, 8803,
        8804, 8805, 8806
        )
        THEN UNGROUP = 1;
        ELSE IF DIDX IN (
102, 108, 115, 120, 126,
321, 401, 402, 405, 412,
416, 420, 501, 502, 505,
507, 516, 518, 528, 533,
602, 603, 604, 606, 610,
611, 613, 615, 618, 621,
623, 701, 710, 711, 807,
822, 823, 824, 915, 1008,
1010, 1012, 1013, 1014, 1101,
1103, 1109, 1110, 1114, 1121,
1502, 1503, 1505, 1605, 1606,
1607, 1701, 1703, 1704, 1708,
1713, 1801, 1803, 1807, 1808, 
2104, 2111, 2206, 2208, 2302, 
2403, 2404, 2502, 7701, 7702,
7703
        )
        THEN DO;
           DO I = 1 TO &DQ.;
              IF DRGARRY1(I) = DIDX THEN CVARRY(14+I) = 1;
           END;
        END;
        ELSE IF MDC IN (
1, 3, 4, 5, 6,
7, 8, 9, 10, 11,
15, 16, 17, 21, 22,
23, 24
        ) 
        THEN DO;
           DO I = 1 TO &MQ.;
              IF MDCARRY1(I) = MDC THEN CVARRY(14+&DQ.+I) = 1;
           END;
        END;
        ELSE IF MDC IN (
12, 18, 25
        ) THEN CVARRY(14+&DQ.+&MQ.+1) = 1;
        ELSE CVARRY(14+&DQ.+&MQ.+2) = 1;

        DO I = 1 TO 46;
           CVARRY(14+&DQ.+&MQ.+2+I) = CCSARRY(I);
        END;

        IF G&PD. IN (1) THEN CVARRY(14+&DQ.+&MQ.+2+46+1) = 1;
        IF G&PD. IN (2) THEN CVARRY(14+&DQ.+&MQ.+2+46+2) = 1;
        IF G&PD. IN (3) THEN CVARRY(14+&DQ.+&MQ.+2+46+3) = 1;

        %END;

        IF SEXCAT IN (2) THEN CVARRY(1) = 1;
        ELSE CVARRY(1) = 0;

        IF PAGECAT IN (2,3,4,5) THEN DO;
           IF PAGECAT IN (2)      THEN CVARRY(11) = 1;
           ELSE IF PAGECAT IN (3) THEN CVARRY(12) = 1;
           ELSE IF PAGECAT IN (4) THEN CVARRY(13) = 1;
           ELSE                        CVARRY(14) = 1;
        END;
        ELSE IF AGEDCAT IN (2,3,4) THEN DO;
           IF AGEDCAT IN (2)      THEN CVARRY(8) = 1;
           ELSE IF AGEDCAT IN (3) THEN CVARRY(9) = 1;
           ELSE                        CVARRY(10) = 1;
        END;
        ELSE DO;
           IF BWHTCAT IN (1)      THEN CVARRY(2) = 1;
           ELSE IF BWHTCAT IN (2) THEN CVARRY(3) = 1;
           ELSE IF BWHTCAT IN (3) THEN CVARRY(4) = 1;
           ELSE IF BWHTCAT IN (4) THEN CVARRY(5) = 1;
           ELSE IF BWHTCAT IN (5) THEN CVARRY(6) = 1;
           ELSE                        CVARRY(7) = 1;
        END;

        %IF &N. = 02 %THEN %DO;
           CVARRY(10) = MAX(CVARRY(10),CVARRY(9),CVARRY(8),
                            CVARRY(7),CVARRY(6),CVARRY(5),
                            CVARRY(4),CVARRY(3),CVARRY(2));
        %END;
        %ELSE %IF &N. = 04 %THEN %DO;
           CVARRY(3) = MAX(CVARRY(3),CVARRY(2));
        %END;
        %ELSE %IF &N. = 05 %THEN %DO;
           CVARRY(7) = MAX(CVARRY(7),CVARRY(6),CVARRY(5),
                           CVARRY(4),CVARRY(3),CVARRY(2));
           CVARRY(9) = MAX(CVARRY(9),CVARRY(8));
        %END;
        %ELSE %IF &N. = 06 %THEN %DO;
           CVARRY(14+&DQ.+&MQ.+2+46+6) = MAX(CVARRY(14+&DQ.+&MQ.+2+46+6),
                                             CVARRY(14+&DQ.+&MQ.+2+46+5));
        %END;
        %ELSE %IF &N. = 08 %THEN %DO;
           CVARRY(9) = MAX(CVARRY(9),CVARRY(8),CVARRY(7),
                           CVARRY(6),CVARRY(5),CVARRY(4),
                           CVARRY(3),CVARRY(2));
        %END;
        %ELSE %IF &N. = 09 %THEN %DO;
           CVARRY(7) = MAX(CVARRY(7),CVARRY(6),CVARRY(5),
                           CVARRY(4),CVARRY(3),CVARRY(2));
        %END;
        %ELSE %IF &N. = 10 %THEN %DO;
           CVARRY(8) = MAX(CVARRY(8),CVARRY(7),CVARRY(6),
                           CVARRY(5),CVARRY(4),CVARRY(3),
                           CVARRY(2));
        %END;
        %ELSE %IF &N. = 11 %THEN %DO;
           CVARRY(7) = MAX(CVARRY(7),CVARRY(6),CVARRY(5),
                           CVARRY(4),CVARRY(3),CVARRY(2));
           CVARRY(10) = MAX(CVARRY(10),CVARRY(9),CVARRY(8));
           CVARRY(13) = MAX(CVARRY(13),CVARRY(12),CVARRY(11));
           CVARRY(14+&DQ.+&MQ.+2+46+3) = MAX(CVARRY(14+&DQ.+&MQ.+2+46+3),
                                             CVARRY(14+&DQ.+&MQ.+2+46+2),
                                             CVARRY(14+&DQ.+&MQ.+2+46+1));
        %END;
        %ELSE %IF &N. = 12 %THEN %DO;
           CVARRY(3) = MAX(CVARRY(3),CVARRY(2));
        %END;

        %MEND;

        %CV;

    RUN;

    * --- THIS DATA STEP READS THE REGRESSION COEFFICIENTS FOR EACH - ;
    * --- COVARIATE.                                                - ;

    DATA TEMP2(KEEP=INTERCEP CV1-CV162 
                    _NAME_ _TYPE_ _LINK_ _LNLIKE_ _STATUS_);
        LENGTH INTERCEP CV1-CV162 
               _LNLIKE_ 8 STATUS 3 _NAME_ _TYPE_ _LINK_ $8 _STATUS_ $11;
        INFILE COVARP MISSOVER LRECL=3000;
        INPUT  N INTERCEP CV1-CV162 
               _NAME_ _TYPE_ _LINK_ _LNLIKE_ STATUS _STATUS_;

        IF N = &N.;

    RUN;

    * --- THIS PROC CALCULATES A PREDICTED PDO FOR EACH OBSERVATION  - ;
    * --- USING THE ACTUAL COVARIATES AND THE ESTIMATED COEFFICIENTS - ;
    * --- THE PROVIDER EFFECT IS CALCULATED BY SUBTRACTING THE       - ;
    * --- PREDICTION FROM THE ACTUAL ON EACH OBSERVATION, AND        - ;
    * --- CALCULATING THE MEAN DIFFERENCE FOR THE PROVIDER.          - ;

    PROC SCORE DATA=TEMP1 SCORE=TEMP2 TYPE=PARMS OUT=TEMP1Y;
    VAR CV1-CV162;
    RUN;

    %let dsid=%sysfunc(open(temp1y));
    %let dnum=%sysfunc(attrn(&dsid,nobs));
    %let drc=%sysfunc(close(&dsid));

    %if &dnum ne 0 %then %do;

    DATA   TEMP1Y;
    SET    TEMP1Y;

    EHAT = EXP(MHAT)/(1 + EXP(MHAT));
    PHAT = EHAT * (1 - EHAT);

    RUN;

    PROC   SUMMARY DATA=TEMP1Y;
    CLASS  HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT;
    VAR    T&PD. EHAT PHAT;
    OUTPUT OUT=R&PD. SUM(T&PD. EHAT PHAT)=T&PD. EHAT PHAT
                     SUMWGT(T&PD.)=P&PD.;
    WEIGHT DISCWT;
    RUN;

    DATA   R&PD.(KEEP=HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT _TYPE_
                      E&PD. R&PD. L&PD. U&PD. P&PD. S&PD. X&PD. V&PD.);
    SET    R&PD.;

    IF _TYPE_ &TYPELVLP;

    %INCLUDE MSXP;
    IF &N. =  1 THEN SUB_N = 1;
    IF &N. =  2 THEN SUB_N = 2;
    IF &N. =  4 THEN SUB_N = 3;
    IF &N. =  5 THEN SUB_N = 4;
    IF &N. =  6 THEN SUB_N = 5;
    IF &N. =  8 THEN SUB_N = 6;
    IF &N. =  9 THEN SUB_N = 7;
    IF &N. = 10 THEN SUB_N = 8;
    IF &N. = 11 THEN SUB_N = 9;
    IF &N. = 12 THEN SUB_N = 10;
 
    E&PD. = EHAT / P&PD.;
    THAT = T&PD. / P&PD.;
 
    IF _TYPE_ IN (0,64) THEN DO;
       R&PD.   = (THAT / E&PD.) * ARRYP3(SUB_N);
       SE&PD.  = (ARRYP3(SUB_N) / E&PD.) * (1 / P&PD.) * SQRT(PHAT);
       V&PD.   = SE&PD.**2;
       SN&PD.  = ARRYP2(SUB_N) / (ARRYP2(SUB_N) + (V&PD. / P&PD.));
       S&PD.   = (R&PD. * SN&PD.) + ((1 -  SN&PD.) * ARRYP3(SUB_N));
       X&PD.   = SQRT(ARRYP2(SUB_N)- (SN&PD. * ARRYP2(SUB_N)));
    END;
    ELSE DO;
       R&PD.   = (THAT / E&PD.);
       SE&PD.  = (1 / E&PD.) * (1 / P&PD.) * SQRT(PHAT);
       S&PD.   = .;
       X&PD.   = .;
    END;

   L&PD.   = R&PD. - (1.96 * SE&PD.);
   IF L&PD. < 0 THEN L&PD. = 0;
   U&PD.   = R&PD. + (1.96 * SE&PD.);

   RUN;

   %end;
   %else %do;

   DATA R&PD.;
      HOSPID=.;BWHTCAT=.;AGEDCAT=.;PAGECAT=.;SEXCAT=.;PAYCAT=.;RACECAT=0.;TYPE_=0;
      E&PD=.;R&PD=.;L&PD=.;U&PD=.;P&PD=.;S&PD=.;X&PD=.;V&PD=.;
      OUTPUT;
   RUN;

   %end;

   PROC   DATASETS NOLIST;
   DELETE TEMP1 TEMP1Y TEMP2;
   RUN;

%MEND;

%MOD3(1,PPD01,43,13);
%MOD3(2,PPD02,27,10);
%MOD3(4,PPD04,2,2);
%MOD3(5,PPD05,6,12);
%MOD3(6,PPD06,2,2);
%MOD3(8,PPD08,4,2);
%MOD3(9,PPD09,24,9);
%MOD3(10,PPD10,36,11);
%MOD3(11,PPD11,2,2);
%MOD3(12,PPD12,76,17);

* --- MERGES THE AREA ADJUSTED RATES FOR EACH PD. PREFIX FOR THE - ;
* --- ADJUSTED RATES IS (R) AND EXPECTED RATES IS (E).           - ;

DATA RISKADJ;
    MERGE RPPD01(KEEP=HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT 
                      EPPD01 RPPD01 LPPD01 UPPD01 PPPD01 SPPD01 XPPD01 VPPD01)
          RPPD02(KEEP=HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT 
                      EPPD02 RPPD02 LPPD02 UPPD02 PPPD02 SPPD02 XPPD02 VPPD02)
          RPPD04(KEEP=HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT 
                      EPPD04 RPPD04 LPPD04 UPPD04 PPPD04 SPPD04 XPPD04 VPPD04)
          RPPD05(KEEP=HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT 
                      EPPD05 RPPD05 LPPD05 UPPD05 PPPD05 SPPD05 XPPD05 VPPD05)
          RPPD06(KEEP=HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT 
                      EPPD06 RPPD06 LPPD06 UPPD06 PPPD06 SPPD06 XPPD06 VPPD06)
          RPPD08(KEEP=HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT 
                      EPPD08 RPPD08 LPPD08 UPPD08 PPPD08 SPPD08 XPPD08 VPPD08)
          RPPD09(KEEP=HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT 
                      EPPD09 RPPD09 LPPD09 UPPD09 PPPD09 SPPD09 XPPD09 VPPD09)
          RPPD10(KEEP=HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT 
                      EPPD10 RPPD10 LPPD10 UPPD10 PPPD10 SPPD10 XPPD10 VPPD10)
          RPPD11(KEEP=HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT 
                      EPPD11 RPPD11 LPPD11 UPPD11 PPPD11 SPPD11 XPPD11 VPPD11)
          RPPD12(KEEP=HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT 
                      EPPD12 RPPD12 LPPD12 UPPD12 PPPD12 SPPD12 XPPD12 VPPD12);
    BY HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT;

    %LBL1;
    %LBL2;
    %LBL3;

RUN;

*==================================================================;
*  Title:  PROGRAM A3  PART II:  MERGE PROVIDER RATES FOR AHRQ
*  PEDIATRIC QUALITY INDICATORS
*
*  Description:  MERGED RATES FOR PEDIATRIC QUALITY INDICATORS
*
*          >>>  VERSION 3.1, February 2007 <<<
*
*===================================================================;

TITLE2 'PROGRAM P3 PART II';
TITLE3 'AHRQ PEDIATRIC QUALITY INDICATORS: PROVIDER-LEVEL MERGED FILES';

* ---------------------------------------------------------------- ;
* --- PEDIATRIC QUALITY INDICATOR MERGED RATES                   - ;
* ---------------------------------------------------------------- ;

DATA OUTP3.&OUTFILP3.;
    MERGE INP3.&INFILP3Y.(
               KEEP=HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT _TYPE_ 
                    TPPD01-TPPD13 PPPD01-PPPD06 PPPD08-PPPD13 OPPD01-OPPD06 OPPD08-OPPD13)
          RISKADJ(
               KEEP=HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT  
                    EPPD01 EPPD02 EPPD04-EPPD06 EPPD08-EPPD12
                    RPPD01 RPPD02 RPPD04-RPPD06 RPPD08-RPPD12
                    LPPD01 LPPD02 LPPD04-LPPD06 LPPD08-LPPD12
                    UPPD01 UPPD02 UPPD04-UPPD06 UPPD08-UPPD12
                    SPPD01 SPPD02 SPPD04-SPPD06 SPPD08-SPPD12
                    XPPD01 XPPD02 XPPD04-XPPD06 XPPD08-XPPD12
                    VPPD01 VPPD02 VPPD04-VPPD06 VPPD08-VPPD12);
    BY HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT;

    ARRAY ARRY1{10} EPPD01 EPPD02 EPPD04-EPPD06 EPPD08-EPPD12;
    ARRAY ARRY2{10} RPPD01 RPPD02 RPPD04-RPPD06 RPPD08-RPPD12;
    ARRAY ARRY3{10} LPPD01 LPPD02 LPPD04-LPPD06 LPPD08-LPPD12;
    ARRAY ARRY4{10} UPPD01 UPPD02 UPPD04-UPPD06 UPPD08-UPPD12;
    ARRAY ARRY5{10} SPPD01 SPPD02 SPPD04-SPPD06 SPPD08-SPPD12;
    ARRAY ARRY6{10} XPPD01 XPPD02 XPPD04-XPPD06 XPPD08-XPPD12;
    ARRAY ARRY7{10} VPPD01 VPPD02 VPPD04-VPPD06 VPPD08-VPPD12;
    ARRAY ARRY8{10} PPPD01 PPPD02 PPPD04-PPPD06 PPPD08-PPPD12;

    DO I = 1 TO 10;
       IF ARRY8(I) <= 2 THEN DO;
          ARRY1(I) = .; ARRY2(I) = .; ARRY3(I) = .; ARRY4(I) = .;
          ARRY5(I) = .; ARRY6(I) = .; ARRY7(I) = .; 
       END;
    END;

    DROP I;

RUN;

* -------------------------------------------------------------- ;
* --- CONTENTS AND MEANS OF PROVIDER-LEVEL MERGED FILE --------- ;
* -------------------------------------------------------------- ;

PROC CONTENTS DATA=OUTP3.&OUTFILP3. POSITION;
RUN;

PROC MEANS DATA=OUTP3.&OUTFILP3. (WHERE=(_TYPE_ IN (64))) N NMISS MIN MAX MEAN SUM;
    TITLE4 "SUMMARY OF PROVIDER-LEVEL RATES (_TYPE_=64)";
RUN;

* -------------------------------------------------------------- ;
* --- PRINT PROVIDER MERGED FILE ------------------------------- ;
* -------------------------------------------------------------- ;

%PRT2


* -------------------------------------------------------------- ;
* --- WRITE SAS OUTPUT DATA SET TO COMMA-DELIMITED TEXT FILE --- ;
* --- FOR EXPORT INTO SPREADSHEETS ----------------------------- ;
* -------------------------------------------------------------- ;

%TEXT
